# 🏃‍♀️Runhouse🏠

The [Runhouse](https://www.run.house) Python client provides a convenient way to access and effortlessly dispatch distributed training workloads to a pool of compute inside your own cloud.
## 📦 Installation
This library requires Python 3.8 – 3.12.

Install the package with `pip`:

```bush
pip install runhouse
```

## 🚀 Getting Started
For a detailed walkthrough and usage guide, see our [docs](https://www.run.house/docs) and [examples](https://www.run.house/examples).


## 🙋‍♂️ Getting Help

For any question or support request you may have, please email us (support@run.house) or message us on [Discord](https://discord.gg/RnhB6589Hs).
